@@ -8,13 +8,13 @@
  */
 string
 medusa::long2text(const long value) {
-  char buffer[32];
+  char buf[32];
 
   /* Small value. */
   long magn = labs(value);
   if(magn < 1000) {
-    sprintf(buffer, "%d", (int)value);
-    return string(buffer);
+    snprintf(buf, sizeof(buf), "%d", (int)value);
+    return string(buf);
   }
 
   /* Collect thousand-sets. */
@@ -29,9 +29,9 @@ medusa::long2text(const long value) {
   string s; int sign = 1;
   if(value < 0) sign = -1;
   for(int i = (int)(segments.size() - 1); i >= 0; i--) {
-    if(s.size() < 1) sprintf(buffer, "%d", sign*segments[i]);
-    else sprintf(buffer, ",%03d", segments[i]);
-    s += string(buffer);
+    if(s.size() < 1) snprintf(buf, sizeof(buf), "%d", sign*segments[i]);
+    else snprintf(buf, sizeof(buf), ",%03d", segments[i]);
+    s += string(buf);
   }
   return s;
 }
